* {
  font-family: Arial, Helvetica, sans-serif;
  scrollbar-width: none;
  -ms-overflow-style: none;
  ::-webkit-scrollbar {
    display: none;
  }
}

body {
  width: 100vw;
  max-width: 1024px;
  margin: 0 auto;
}
.container {
  margin: 0;
  border: 0;
  padding: 0;
}
.code {
  font-family: "Courier New", Courier, monospace;
}
#header-container {
  margin: 1rem auto;
  overflow: hidden;
  p {
    overflow: scroll;
    white-space: nowrap;
  }
}
#main-container {
  margin: 1rem auto;
  width: fit-content;
}
#main-table {
  text-align: center;
  th, td {
    padding: 0.5rem 1rem;
  }
}
